/* $Id: iconv_test.c,v 1.2 2003/11/27 10:00:27 yoshfuji Exp $ */
/*
 * Copyright (C)2003 Hideaki YOSHIFUJI.
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
#include <iconv.h>
#include <errno.h>
#include "config.h"

char *str = "ƥ";

char *charsets[] = {
#if defined(CHARSETOK_ISO2022JP)
	CHARSETOK_ISO2022JP,
#endif
#if defined(CHARSETOK_EUCJP)
	CHARSETOK_EUCJP,
#endif
#if defined(CHARSETOK_SJIS)
	CHARSETOK_SJIS,
#endif
#if defined(CHARSETOK_UTF8)
	CHARSETOK_UTF8,
#endif
	"invalid",
};

int main(int argc, char **argv)
{
	int i, maxcs = sizeof(charsets)/sizeof(charsets[0]);
	iconv_t cd;
	int valid[maxcs];
	
	for (i = 0; i < maxcs; i++) {
		cd = iconv_open(charsets[i], charsets[i]);
		if (cd == (iconv_t)(-1)) {
			printf("%s: unavailable\n", charsets[i]);
			valid[i] = 0;
		} else {
			printf("%s: ok\n", charsets[i]);
			iconv_close(cd);
			valid[i] = 1;
		}
	}

	puts("====");

	for (i = 0; i < maxcs; i++) {
		int j;
		if (!valid[i])
			continue;
		for (j = 0; j < maxcs; j++) {
			if (!valid[j])
				continue;
			printf("%s <= %s: ", charsets[i], charsets[j]);
			cd = iconv_open(charsets[i], charsets[j]);
			if (cd == (iconv_t)(-1)) {
				printf("error (%s)", strerror(errno));
			} else {
				iconv_close(cd);
				printf("ok");
			}
			printf("\n");
		}
		puts("----");
	}
	exit(0);
}

